{# Global table of contents #}

<h1 class="tocheader">
  <a href="{{ pathto(master_doc)|e }}">{{ _('Contents') }}</a>
</h1>

{{ toctree(includehidden=theme_globaltoc_includehidden, collapse=theme_globaltoc_collapse, maxdepth=theme_globaltoc_maxdepth) }}
