{# Domain index (Python module index) #}

{%- extends "layout.html" -%}
{%- set title = indextitle -%}

{% block body %}

  {%- set groupid = idgen() -%}

  <h1>{{ indextitle }}</h1>

  <div class="modindex-jumpbox">
    {% for letter, entries in genindexentries %}
      <a href="#{{ letter }}"><strong>{{ letter }}</strong></a>
      {% if not loop.last %}| {% endif %}
    {%- endfor %}
  </div>

  {%- for letter, entries in content -%}
    <h2 id="{{ letter }}">{{ letter }}</h2>
    <ul>

      {%- for (name, grouptype, page, anchor, extra, qualifier, description) in entries %}
        <li>
          {% if page %}
            <a href="{{ pathto(page)|e }}#{{ anchor }}">
          {% endif -%}

          <code class="xref">{{ name|e }}</code>

          {%- if page %}
            </a>
          {% endif %}

          {%- if extra %}
            <em>({{ extra|e }})</em>
          {%- endif -%}

          {% if qualifier %}
            <strong>{{ qualifier|e }}:</strong>
          {% endif %}

          <em>{{ description|e }}</em>
        </li>
      {%- endfor %}

    </ul>
  {%- endfor %}

{% endblock %}
